==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/admin/includes/footer.php <==
<?php
/* --------------------------------------------------------------
   footer.php 2017-03-09
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]

   IMPORTANT! THIS FILE IS DEPRECATED AND WILL BE REPLACED IN THE FUTURE. 
   MODIFY IT ONLY FOR FIXES. DO NOT APPEND IT WITH NEW FEATURES, USE THE
   NEW GX-ENGINE LIBRARIES INSTEAD.		
   --------------------------------------------------------------

   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(footer.php,v 1.12 2003/02/17); www.oscommerce.com 
   (c) 2003	 nextcommerce (footer.php,v 1.11 2003/08/18); www.nextcommerce.org
   (c) 2003 XT-Commerce - community made shopping http://www.xt-commerce.com ($Id: footer.php 899 2005-04-29 02:40:57Z hhgag $)

   Released under the GNU General Public License 
   --------------------------------------------------------------*/
?>

	<div class="main-bottom-footer"
	     data-gx-compatibility="sticky_footer bottom_save_bar">
		<?php require DIR_FS_ADMIN . 'html/compatibility/main_bottom_footer.php'; ?>
	</div>

</div>

	
	<div class="main-bottom-copyright">
		
		<table border="0" width="100%" cellspacing="0" cellpadding="2" id="gm_footer">
			<tr>
				<td align="center">
				
					<?php
						/*
							The following copyright announcement is in compliance
							to section 2c of the GNU General Public License, and
							thus can not be removed, or can only be modified
							appropriately.
	
							Please leave this comment intact together with the
							following copyright announcement.
	
							Copyright announcement changed due to the permissions
							from LG Hamburg from 28th February 2003 / AZ 308 O 70/03
						*/
					?>
					<strong><a href="https://www.gambio.de" target="_blank"><strong>Gambio.de</strong></a> - Gambio Admin &copy; 
					<?php echo date('Y'); ?> Gambio GmbH</strong> Gambio GmbH provides no warranty. The Shopsoftware is redistributable under the 
					<a href="http://www.gnu.org/licenses/gpl-2.0.html" target="_blank">GNU General Public License (Version 2)</a>
					based on: E-Commerce Engine Copyright &copy; 2006 <a href="http://www.xt-commerce.com" target="_blank">xt:Commerce</a>, 
					<a href="http://www.xt-commerce.com" target="_blank">xt:Commerce</a> provides no warranty.
					&nbsp;<a href="./credits.php">Credits</a>
				</td>
			</tr>
		</table>
	</div>
</div>

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/admin/includes/footer.php <==
<?php
/* --------------------------------------------------------------
   footer.php 2017-03-09
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]

   IMPORTANT! THIS FILE IS DEPRECATED AND WILL BE REPLACED IN THE FUTURE. 
   MODIFY IT ONLY FOR FIXES. DO NOT APPEND IT WITH NEW FEATURES, USE THE
   NEW GX-ENGINE LIBRARIES INSTEAD.		
   --------------------------------------------------------------

   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(footer.php,v 1.12 2003/02/17); www.oscommerce.com 
   (c) 2003	 nextcommerce (footer.php,v 1.11 2003/08/18); www.nextcommerce.org
   (c) 2003 XT-Commerce - community made shopping http://www.xt-commerce.com ($Id: footer.php 899 2005-04-29 02:40:57Z hhgag $)

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

use Gambio\Admin\Application\GambioAdminBootstrapper;
use Gambio\Admin\Layout\Renderer\GambioAdminLoader;
use Gambio\Core\Application\Application;
use Gambio\Core\Application\DependencyInjection\LeagueContainer;
use Gambio\Core\TemplateEngine\Collection\LayoutDataCollection;

global $adminLayoutData;
if ($adminLayoutData === null) {
    $application = LegacyDependencyContainer::getInstance();
    $bootstrapper = new GambioAdminBootstrapper();
    $bootstrapper->boot($application);

    /** @var GambioAdminLoader $loader */
    $adminLayoutLoader = $application->get(GambioAdminLoader::class);
    $adminLayoutData = new LayoutDataCollection();
    $adminLayoutLoader->load($adminLayoutData);
}

?>

	<div class="main-bottom-footer"
	     data-gx-compatibility="sticky_footer bottom_save_bar">
		<?php require DIR_FS_ADMIN . 'html/compatibility/main_bottom_footer.php'; ?>
	</div>

</div>


	<div class="main-bottom-copyright">

		<table border="0" width="100%" cellspacing="0" cellpadding="2" id="gm_footer">
			<tr>
				<td align="center">

					<?php
						/*
							The following copyright announcement is in compliance
							to section 2c of the GNU General Public License, and
							thus can not be removed, or can only be modified
							appropriately.

							Please leave this comment intact together with the
							following copyright announcement.

							Copyright announcement changed due to the permissions
							from LG Hamburg from 28th February 2003 / AZ 308 O 70/03
						*/
					?>
					<strong><a href="https://www.gambio.de" target="_blank"><strong>Gambio.de</strong></a> - Gambio Admin &copy;
					<?php echo date('Y'); ?> Gambio GmbH</strong> Gambio GmbH provides no warranty. The Shopsoftware is redistributable under the
					<a href="http://www.gnu.org/licenses/gpl-2.0.html" target="_blank">GNU General Public License (Version 2)</a>
					based on: E-Commerce Engine Copyright &copy; 2006 <a href="http://www.xt-commerce.com" target="_blank">xt:Commerce</a>,
					<a href="http://www.xt-commerce.com" target="_blank">xt:Commerce</a> provides no warranty.
					&nbsp;<a href="./credits.php">Credits</a>
				</td>
			</tr>
		</table>
	</div>
</div>

<?php if($adminLayoutData->get('enable_legacy_dynamic_script_assets')): ?>
  <?= $adminLayoutData->get('dynamic_script_assets') ?>
<?php endif; ?>
